<?php
/**
 * @package    JDiDEAL
 *
 * @author     Roland Dalmulder <contact@rolandd.com>
 * @copyright  Copyright (C) 2009 - 2021 RolandD Cyber Produksi. All rights reserved.
 * @license    GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 * @link       https://rolandd.com
 */

defined('_JEXEC') or die;

use Joomla\CMS\Component\ComponentHelper;
use Joomla\CMS\Factory;
use Joomla\CMS\Filesystem\File;
use Joomla\CMS\Language\Text;

/**
 * Load the RO Payments installer.
 *
 * @package  JDiDEAL
 *
 * @since    2.0
 */
class PlgsystemrseprojdidealInstallerScript
{
	/**
	 * Run the preflight operations.
	 *
	 * @param   object  $parent  The parent class.
	 *
	 * @return  bool  True on success | False on failure.
	 *
	 * @since   4.7.0
	 *
	 * @throws  Exception
	 */
	public function preflight($parent)
	{
		// Check if RO Payments is installed
		if ($parent === 'install' && ComponentHelper::isInstalled('com_jdidealgateway') === 0)
		{
			Factory::getApplication()->enqueueMessage(Text::_('PLG_RSEVENTS_JDIDEAL_JDIDEALGATEWAY_NOT_INSTALLED'),
				'error');

			return false;
		}

		return true;
	}

	/**
	 * Run the postflight operations.
	 *
	 * @param   object  $parent  The parent class.
	 *
	 * @return bool True on success | False on failure.
	 *
	 * @since   2.0
	 *
	 * @throws  Exception
	 */
	public function postflight($parent)
	{
		$app = Factory::getApplication();
		/** @var JDatabaseDriver $db */
		$db = Factory::getDbo();

		// Run the uninstall SQL
		$queries = $db->splitSql(
			file_get_contents(JPATH_SITE . '/plugins/system/rseprojdideal/sql/uninstall.mysql.rseprojdideal.sql')
		);

		foreach ($queries as $index => $query)
		{
			$db->setQuery($query)->execute();
		}

		// Run the install SQL
		$queries = $db->splitSql(
			file_get_contents(JPATH_SITE . '/plugins/system/rseprojdideal/sql/install.mysql.rseprojdideal.sql')
		);

		foreach ($queries as $index => $query)
		{
			$db->setQuery($query)->execute();
		}

		// Enable the plugin
		$query = $db->getQuery(true)
			->update($db->quoteName('#__extensions'))
			->set($db->quoteName('enabled') . ' =  1')
			->where($db->quoteName('element') . ' = ' . $db->quote('rseprojdideal'))
			->where($db->quoteName('type') . ' = ' . $db->quote('plugin'));
		$db->setQuery($query);

		if (!$db->execute())
		{
			$app->enqueueMessage(
				Text::sprintf('PLG_RSEPRO_PAYMENT_JDIDEAL_PLUGIN_NOT_ENABLED', $db->getErrorMsg()),
				'error'
			);

			return false;
		}

		// Remove any old language files
		$languageFiles = [
			JPATH_ADMINISTRATOR . '/language/en-GB/en-GB.plg_system_rseprojdideal.ini',
			JPATH_ADMINISTRATOR . '/language/en-GB/en-GB.plg_system_rseprojdideal.sys.ini',
			JPATH_ADMINISTRATOR . '/language/nl-NL/nl-NL.plg_system_rseprojdideal.ini',
			JPATH_ADMINISTRATOR . '/language/nl-NL/nl-NL.plg_system_rseprojdideal.sys.ini'
		];

		array_walk($languageFiles,
			static function ($languageFile)
			{
				if (file_exists($languageFile))
				{
					File::delete($languageFile);
				}
			}
		);

		$app->enqueueMessage(Text::_('PLG_RSEPRO_PAYMENT_JDIDEAL_PLUGIN_ENABLED'));

		return true;
	}

	/**
	 * Cleanup after uninstallation.
	 *
	 * @param   object  $parent  The parent class.
	 *
	 * @return  void.
	 *
	 * @since   2.0
	 */
	public function uninstall($parent)
	{
		File::delete(JPATH_ADMINISTRATOR . '/components/com_jdidealgateway/models/addons/rseventspro.php');
	}
}
